@@ -4,13 +4,12 @@ use strict;
 use warnings;
 
 use Carp;
-use Data::Dumper;
 
 use IUP::Internal::LibraryIup;
 use IUP::Constants;
 
 # following recommendation from http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
-our $VERSION = "0.001_08";
+our $VERSION = "0.002_01";
 $VERSION = eval $VERSION;
 
 sub BEGIN {
@@ -32,10 +31,9 @@ sub import {
   my %tags = (
      #UPDATE when element list change
      ':basic' => [qw/Constants Button Cbox Clipboard ColorBar ColorBrowser ColorDlg Dial Dialog FileDlg Fill FontDlg Frame
-                     Hbox Image Item Label LayoutDialog List Menu MessageDlg Normalizer ProgressBar Radio 
+                     Hbox Image Item Label List Menu MessageDlg Normalizer ProgressBar Radio 
                      Sbox Separator Spin SpinBox Split Submenu Tabs Text Timer Toggle Tree User Val Vbox Zbox/], 
-		     #xxxFIXME add OleControl conditionally
-     ':extended' => [qw/Matrix Cells Canvas CanvasGL PPlot/],
+     ':extended' => [qw/Matrix Cells Canvas CanvasGL PPlot LayoutDialog ElementPropertiesDialog/],
      ':all' => [],
   );  
   @{$tags{':all'}} = ( @{$tags{':basic'}}, @{$tags{':extended'}} );
